    /*

    Requires the Qt widget libraries, available at no cost at
    http://www.troll.no

    Copyright (C) 1997 Frithjof Brestrich
                       brestrich@kde.org


    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    */

#ifndef _TOPLEVEL_H_
#define _TOPLEVEL_H_

#include "kvidtune.h"

#include <qapp.h>
#include <kmenubar.h>
#include <kapp.h> 
#include <ktopwidget.h>
#include <ktoolbar.h>
#include <kstatusbar.h>
#include <kpanner.h>

#include "xf86vidmode.h"

class TopLevel : public KTopLevelWidget
{
  Q_OBJECT;
  
public:

  TopLevel(XF86VidMode *vmode);
  ~TopLevel();

  void configLoad();
  void configStore();

protected:
  QPopupMenu    *menu_file;
  QPopupMenu    *menu_mode;
  QPopupMenu    *menu_info;
  QPopupMenu    *menu_options;
  QPopupMenu    *menu_help;

  XF86VidMode     *VidMode;
  XF86VidModeLine *VML_Akt, *VML_Undo, *VML_Restore;
  bool            LifeAdjust;

  int           CfgDisplayWarning;
  QString       CfgConfigFile;
  QString       CfgWorkingDirectory;

  void setupMenuBar();
  void setupToolBar();
  void setupStatusBar();
  void setupMainWidget();

  void ProcessStatus(const char *topic, bool msgbox = TRUE);
  void ProcessStatus(const char *topic, const char *msg, bool msgbox = TRUE);

  void displayWarning();

  void update_modeinfo();

  bool vidcmd_apply( bool doit = FALSE );

private:

  KMenuBar   *menubar;
  KToolBar   *toolbar;
  KStatusBar *statusbar;
  KVidTune   *vidtune;

  const int ID_STATUS_GENERAL = 1;
  const int ID_TOOLBAR_PREV   = 2;
  const int ID_TOOLBAR_NEXT   = 3;

public slots:

  void resizeOnFloating();

  void vidmov_left(int steps);
  void vidmov_right(int steps);
  void vidmov_up(int steps);
  void vidmov_down(int steps);
  void vidsiz_hmore(int steps);
  void vidsiz_hless(int steps);
  void vidsiz_vmore(int steps);
  void vidsiz_vless(int steps);
  void videomode(int mode);
  void vidcmd_lifeadj(bool state);
  void vidcmd_test();
  void vidcmd_undo();
  void vidcmd_restore();
  void vidflg_interlace(bool state);
  void vidflg_doublescan(bool state);
  void vidflg_composite(bool state);
  void vidflg_phsync(bool state);
  void vidflg_nhsync(bool state);
  void vidflg_pvsync(bool state);
  void vidflg_nvsync(bool state);
  void vidflg_pcsync(bool state);
  void vidflg_ncsync(bool state);

  void filesave();

  void prevvideomode();
  void nextvideomode();

  void infoxserver();
  void infomonitor();
  void infovideomode();
  void infomodeline();
  
  void optionsconfigure();

  void about();
  void aboutQt();
  void help();

};

#endif
