/*
    Requires the Qt widget libraries, available at no cost at
    http://www.troll.no

    Copyright (C) 1997 Frithjof Brestrich
                       brestrich@kde.org


    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/ 

#ifndef __XF86CFGDATA__
#define __XF86CFGDATA__

#include <qobject.h>
#include <qlist.h>
#include <qlist.h>
#include <qstring.h>
#include <qfile.h>
#include <qtstream.h>

#include "xf86vidmode.h"

struct tXF86CfgEntry {
  QString Key;
  QString Value;
  bool    IsString;
}; 

typedef QList<tXF86CfgEntry> tXF86CfgEntryList; 

struct tXF86CfgDirectory {
  tXF86CfgDirectory( const char *name) { 
    Data.setAutoDelete( TRUE ); 
    Dir.setAutoDelete( TRUE ); 
    Name=name; 
  };
  QString                  Name;
  tXF86CfgEntryList        Data;
  QList<tXF86CfgDirectory> Dir;
};

class XF86ConfigFile : public QObject 
{

private:

  QString            ErrorText;
  tXF86CfgDirectory  *Data;
  QFile              *File;
  QTextStream        *Stream;

protected:

  void SetErrorText(const QString &txt);

  bool OpenFile(const QString &fname, int flags);
  bool CloseFile();

  bool ReadSection(tXF86CfgDirectory *Dir);
  bool WriteSection(tXF86CfgDirectory *Dir, int Deep=0);
  
public:

  XF86ConfigFile();
  virtual ~XF86ConfigFile();

  const QString &LastErrorText();

  bool Load(const QString &fname);
  bool Store(const QString &fname);

  tXF86CfgDirectory* FindSection(const char* name,const char *key,const char* val,
                                 tXF86CfgDirectory* root=NULL);
  tXF86CfgEntry* FindEntry(const char* name, tXF86CfgEntryList* root=NULL);

  bool SetModeLines(char *vendor, char *model, XF86VidModeLine* &modelines, unsigned count);

};

#endif /* __XF86CFGDATA__ */
